# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelasystem.v1 import modelasystem_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2


class ModelaSystemServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelaSystems = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/ListModelaSystems',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.ListModelaSystemsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.ListModelaSystemsResponse.FromString,
                )
        self.CreateModelaSystem = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/CreateModelaSystem',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.CreateModelaSystemRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.CreateModelaSystemResponse.FromString,
                )
        self.GetModelaSystem = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/GetModelaSystem',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.GetModelaSystemRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.GetModelaSystemResponse.FromString,
                )
        self.UpdateModelaSystem = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/UpdateModelaSystem',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.UpdateModelaSystemRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.UpdateModelaSystemResponse.FromString,
                )
        self.DeleteModelaSystem = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/DeleteModelaSystem',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DeleteModelaSystemRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DeleteModelaSystemResponse.FromString,
                )
        self.DownloadLogfile = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/DownloadLogfile',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DownloadLogFileRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DownloadLogFileResponse.FromString,
                )
        self.BackupDatabase = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/BackupDatabase',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupDatabaseRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupDatabaseResponse.FromString,
                )
        self.BackupEtcd = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/BackupEtcd',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupEtcdRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupEtcdResponse.FromString,
                )


class ModelaSystemServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelaSystems(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelaSystem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelaSystem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelaSystem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelaSystem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadLogfile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackupDatabase(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BackupEtcd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelaSystemServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelaSystems': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelaSystems,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.ListModelaSystemsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.ListModelaSystemsResponse.SerializeToString,
            ),
            'CreateModelaSystem': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelaSystem,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.CreateModelaSystemRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.CreateModelaSystemResponse.SerializeToString,
            ),
            'GetModelaSystem': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelaSystem,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.GetModelaSystemRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.GetModelaSystemResponse.SerializeToString,
            ),
            'UpdateModelaSystem': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelaSystem,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.UpdateModelaSystemRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.UpdateModelaSystemResponse.SerializeToString,
            ),
            'DeleteModelaSystem': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelaSystem,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DeleteModelaSystemRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DeleteModelaSystemResponse.SerializeToString,
            ),
            'DownloadLogfile': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadLogfile,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DownloadLogFileRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DownloadLogFileResponse.SerializeToString,
            ),
            'BackupDatabase': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupDatabase,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupDatabaseRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupDatabaseResponse.SerializeToString,
            ),
            'BackupEtcd': grpc.unary_unary_rpc_method_handler(
                    servicer.BackupEtcd,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupEtcdRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupEtcdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelaSystemService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelaSystems(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/ListModelaSystems',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.ListModelaSystemsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.ListModelaSystemsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelaSystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/CreateModelaSystem',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.CreateModelaSystemRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.CreateModelaSystemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelaSystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/GetModelaSystem',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.GetModelaSystemRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.GetModelaSystemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelaSystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/UpdateModelaSystem',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.UpdateModelaSystemRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.UpdateModelaSystemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelaSystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/DeleteModelaSystem',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DeleteModelaSystemRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DeleteModelaSystemResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DownloadLogfile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/DownloadLogfile',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DownloadLogFileRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.DownloadLogFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BackupDatabase(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/BackupDatabase',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupDatabaseRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupDatabaseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BackupEtcd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelasystem.v1.ModelaSystemService/BackupEtcd',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupEtcdRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelasystem_dot_v1_dot_modelasystem__pb2.BackupEtcdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/feature/v1/feature.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/feature/v1/feature.proto\x12\x31github.com.metaprov.modelaapi.services.feature.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xf4\x01\n\x13ListFeaturesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x01\n\x14ListFeaturesResponse\x12S\n\x08\x66\x65\x61tures\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"f\n\x14\x43reateFeatureRequest\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x17\n\x15\x43reateFeatureResponse\"\x96\x01\n\x14UpdateFeatureRequest\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateFeatureResponse\"4\n\x11GetFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x12GetFeatureResponse\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteFeatureResponse2\x98\x08\n\x0e\x46\x65\x61tureService\x12\xc1\x01\n\x0cListFeatures\x12\x46.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest\x1aG.github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/features/{namespace}\x12\xbb\x01\n\rCreateFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/features:\x01*\x12\xc2\x01\n\nGetFeature\x12\x44.github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest\x1a\x45.github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/features/{namespace}/{name}\x12\xf0\x01\n\rUpdateFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/features/{feature.metadata.namespace}/{feature.metadata.name}:\x01*\x12\xcb\x01\n\rDeleteFeature\x12G.github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest\x1aH.github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/features/{namespace}/{name}B3Z1github.com/metaprov/modelaapi/services/feature/v1b\x06proto3')



_LISTFEATURESREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturesRequest']
_LISTFEATURESREQUEST_LABELSENTRY = _LISTFEATURESREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATURESRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturesResponse']
_CREATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureRequest']
_CREATEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['CreateFeatureResponse']
_UPDATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureRequest']
_UPDATEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureResponse']
_GETFEATUREREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureRequest']
_GETFEATURERESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureResponse']
_DELETEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureRequest']
_DELETEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureResponse']
ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATURESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)
_sym_db.RegisterMessage(ListFeaturesRequest.LabelsEntry)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

CreateFeatureRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureRequest)
  })
_sym_db.RegisterMessage(CreateFeatureRequest)

CreateFeatureResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.CreateFeatureResponse)
  })
_sym_db.RegisterMessage(CreateFeatureResponse)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)

UpdateFeatureResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.UpdateFeatureResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureResponse)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

GetFeatureResponse = _reflection.GeneratedProtocolMessageType('GetFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.GetFeatureResponse)
  })
_sym_db.RegisterMessage(GetFeatureResponse)

DeleteFeatureRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureRequest)

DeleteFeatureResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.feature.v1.feature_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.feature.v1.DeleteFeatureResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureResponse)

_FEATURESERVICE = DESCRIPTOR.services_by_name['FeatureService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/feature/v1'
  _LISTFEATURESREQUEST_LABELSENTRY._options = None
  _LISTFEATURESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATURESERVICE.methods_by_name['ListFeatures']._options = None
  _FEATURESERVICE.methods_by_name['ListFeatures']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/features/{namespace}'
  _FEATURESERVICE.methods_by_name['CreateFeature']._options = None
  _FEATURESERVICE.methods_by_name['CreateFeature']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/features:\001*'
  _FEATURESERVICE.methods_by_name['GetFeature']._options = None
  _FEATURESERVICE.methods_by_name['GetFeature']._serialized_options = b'\202\323\344\223\002!\022\037/v1/features/{namespace}/{name}'
  _FEATURESERVICE.methods_by_name['UpdateFeature']._options = None
  _FEATURESERVICE.methods_by_name['UpdateFeature']._serialized_options = b'\202\323\344\223\002F\032A/v1/features/{feature.metadata.namespace}/{feature.metadata.name}:\001*'
  _FEATURESERVICE.methods_by_name['DeleteFeature']._options = None
  _FEATURESERVICE.methods_by_name['DeleteFeature']._serialized_options = b'\202\323\344\223\002!*\037/v1/features/{namespace}/{name}'
  _LISTFEATURESREQUEST._serialized_start=253
  _LISTFEATURESREQUEST._serialized_end=497
  _LISTFEATURESREQUEST_LABELSENTRY._serialized_start=452
  _LISTFEATURESREQUEST_LABELSENTRY._serialized_end=497
  _LISTFEATURESRESPONSE._serialized_start=500
  _LISTFEATURESRESPONSE._serialized_end=632
  _CREATEFEATUREREQUEST._serialized_start=634
  _CREATEFEATUREREQUEST._serialized_end=736
  _CREATEFEATURERESPONSE._serialized_start=738
  _CREATEFEATURERESPONSE._serialized_end=761
  _UPDATEFEATUREREQUEST._serialized_start=764
  _UPDATEFEATUREREQUEST._serialized_end=914
  _UPDATEFEATURERESPONSE._serialized_start=916
  _UPDATEFEATURERESPONSE._serialized_end=939
  _GETFEATUREREQUEST._serialized_start=941
  _GETFEATUREREQUEST._serialized_end=993
  _GETFEATURERESPONSE._serialized_start=995
  _GETFEATURERESPONSE._serialized_end=1109
  _DELETEFEATUREREQUEST._serialized_start=1111
  _DELETEFEATUREREQUEST._serialized_end=1166
  _DELETEFEATURERESPONSE._serialized_start=1168
  _DELETEFEATURERESPONSE._serialized_end=1191
  _FEATURESERVICE._serialized_start=1194
  _FEATURESERVICE._serialized_end=2242
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/meeting/v1/meeting.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/meeting/v1/meeting.proto\x12\x31github.com.metaprov.modelaapi.services.meeting.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xf4\x01\n\x13ListMeetingsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x01\n\x14ListMeetingsResponse\x12S\n\x08meetings\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.MeetingList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x11\n\x0fMeetingResponse\"x\n\x14\x43reateMeetingRequest\x12N\n\x07meeting\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\x12\x10\n\x08password\x18\x02 \x01(\t\"\x17\n\x15\x43reateMeetingResponse\"\x96\x01\n\x14UpdateMeetingRequest\x12N\n\x07meeting\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateMeetingResponse\"4\n\x11GetMeetingRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x12GetMeetingResponse\x12N\n\x07meeting\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Meeting\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteMeetingRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteMeetingResponse2\x98\x08\n\x0eMeetingService\x12\xc1\x01\n\x0cListMeetings\x12\x46.github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest\x1aG.github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/meetings/{namespace}\x12\xbb\x01\n\rCreateMeeting\x12G.github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingRequest\x1aH.github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/meetings:\x01*\x12\xc2\x01\n\nGetMeeting\x12\x44.github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingRequest\x1a\x45.github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/meetings/{namespace}/{name}\x12\xf0\x01\n\rUpdateMeeting\x12G.github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingRequest\x1aH.github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/meetings/{meeting.metadata.namespace}/{meeting.metadata.name}:\x01*\x12\xcb\x01\n\rDeleteMeeting\x12G.github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingRequest\x1aH.github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/meetings/{namespace}/{name}B3Z1github.com/metaprov/modelaapi/services/meeting/v1b\x06proto3')



_LISTMEETINGSREQUEST = DESCRIPTOR.message_types_by_name['ListMeetingsRequest']
_LISTMEETINGSREQUEST_LABELSENTRY = _LISTMEETINGSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMEETINGSRESPONSE = DESCRIPTOR.message_types_by_name['ListMeetingsResponse']
_MEETINGRESPONSE = DESCRIPTOR.message_types_by_name['MeetingResponse']
_CREATEMEETINGREQUEST = DESCRIPTOR.message_types_by_name['CreateMeetingRequest']
_CREATEMEETINGRESPONSE = DESCRIPTOR.message_types_by_name['CreateMeetingResponse']
_UPDATEMEETINGREQUEST = DESCRIPTOR.message_types_by_name['UpdateMeetingRequest']
_UPDATEMEETINGRESPONSE = DESCRIPTOR.message_types_by_name['UpdateMeetingResponse']
_GETMEETINGREQUEST = DESCRIPTOR.message_types_by_name['GetMeetingRequest']
_GETMEETINGRESPONSE = DESCRIPTOR.message_types_by_name['GetMeetingResponse']
_DELETEMEETINGREQUEST = DESCRIPTOR.message_types_by_name['DeleteMeetingRequest']
_DELETEMEETINGRESPONSE = DESCRIPTOR.message_types_by_name['DeleteMeetingResponse']
ListMeetingsRequest = _reflection.GeneratedProtocolMessageType('ListMeetingsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMEETINGSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMEETINGSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsRequest)
  })
_sym_db.RegisterMessage(ListMeetingsRequest)
_sym_db.RegisterMessage(ListMeetingsRequest.LabelsEntry)

ListMeetingsResponse = _reflection.GeneratedProtocolMessageType('ListMeetingsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMEETINGSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.ListMeetingsResponse)
  })
_sym_db.RegisterMessage(ListMeetingsResponse)

MeetingResponse = _reflection.GeneratedProtocolMessageType('MeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _MEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.MeetingResponse)
  })
_sym_db.RegisterMessage(MeetingResponse)

CreateMeetingRequest = _reflection.GeneratedProtocolMessageType('CreateMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingRequest)
  })
_sym_db.RegisterMessage(CreateMeetingRequest)

CreateMeetingResponse = _reflection.GeneratedProtocolMessageType('CreateMeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.CreateMeetingResponse)
  })
_sym_db.RegisterMessage(CreateMeetingResponse)

UpdateMeetingRequest = _reflection.GeneratedProtocolMessageType('UpdateMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingRequest)
  })
_sym_db.RegisterMessage(UpdateMeetingRequest)

UpdateMeetingResponse = _reflection.GeneratedProtocolMessageType('UpdateMeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.UpdateMeetingResponse)
  })
_sym_db.RegisterMessage(UpdateMeetingResponse)

GetMeetingRequest = _reflection.GeneratedProtocolMessageType('GetMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingRequest)
  })
_sym_db.RegisterMessage(GetMeetingRequest)

GetMeetingResponse = _reflection.GeneratedProtocolMessageType('GetMeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.GetMeetingResponse)
  })
_sym_db.RegisterMessage(GetMeetingResponse)

DeleteMeetingRequest = _reflection.GeneratedProtocolMessageType('DeleteMeetingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMEETINGREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingRequest)
  })
_sym_db.RegisterMessage(DeleteMeetingRequest)

DeleteMeetingResponse = _reflection.GeneratedProtocolMessageType('DeleteMeetingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMEETINGRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.meeting.v1.meeting_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.meeting.v1.DeleteMeetingResponse)
  })
_sym_db.RegisterMessage(DeleteMeetingResponse)

_MEETINGSERVICE = DESCRIPTOR.services_by_name['MeetingService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/meeting/v1'
  _LISTMEETINGSREQUEST_LABELSENTRY._options = None
  _LISTMEETINGSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _MEETINGSERVICE.methods_by_name['ListMeetings']._options = None
  _MEETINGSERVICE.methods_by_name['ListMeetings']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/meetings/{namespace}'
  _MEETINGSERVICE.methods_by_name['CreateMeeting']._options = None
  _MEETINGSERVICE.methods_by_name['CreateMeeting']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/meetings:\001*'
  _MEETINGSERVICE.methods_by_name['GetMeeting']._options = None
  _MEETINGSERVICE.methods_by_name['GetMeeting']._serialized_options = b'\202\323\344\223\002!\022\037/v1/meetings/{namespace}/{name}'
  _MEETINGSERVICE.methods_by_name['UpdateMeeting']._options = None
  _MEETINGSERVICE.methods_by_name['UpdateMeeting']._serialized_options = b'\202\323\344\223\002F\032A/v1/meetings/{meeting.metadata.namespace}/{meeting.metadata.name}:\001*'
  _MEETINGSERVICE.methods_by_name['DeleteMeeting']._options = None
  _MEETINGSERVICE.methods_by_name['DeleteMeeting']._serialized_options = b'\202\323\344\223\002!*\037/v1/meetings/{namespace}/{name}'
  _LISTMEETINGSREQUEST._serialized_start=316
  _LISTMEETINGSREQUEST._serialized_end=560
  _LISTMEETINGSREQUEST_LABELSENTRY._serialized_start=515
  _LISTMEETINGSREQUEST_LABELSENTRY._serialized_end=560
  _LISTMEETINGSRESPONSE._serialized_start=563
  _LISTMEETINGSRESPONSE._serialized_end=695
  _MEETINGRESPONSE._serialized_start=697
  _MEETINGRESPONSE._serialized_end=714
  _CREATEMEETINGREQUEST._serialized_start=716
  _CREATEMEETINGREQUEST._serialized_end=836
  _CREATEMEETINGRESPONSE._serialized_start=838
  _CREATEMEETINGRESPONSE._serialized_end=861
  _UPDATEMEETINGREQUEST._serialized_start=864
  _UPDATEMEETINGREQUEST._serialized_end=1014
  _UPDATEMEETINGRESPONSE._serialized_start=1016
  _UPDATEMEETINGRESPONSE._serialized_end=1039
  _GETMEETINGREQUEST._serialized_start=1041
  _GETMEETINGREQUEST._serialized_end=1093
  _GETMEETINGRESPONSE._serialized_start=1095
  _GETMEETINGRESPONSE._serialized_end=1209
  _DELETEMEETINGREQUEST._serialized_start=1211
  _DELETEMEETINGREQUEST._serialized_end=1266
  _DELETEMEETINGRESPONSE._serialized_start=1268
  _DELETEMEETINGRESPONSE._serialized_end=1291
  _MEETINGSERVICE._serialized_start=1294
  _MEETINGSERVICE._serialized_end=2342
# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# setup
# Setup script for installing modela
#
# Author:   Tomer Sagi
# Created:  Sun Fev 14 
#
# Copyright (C) 2016 The modela developers
# For license information, see LICENSE.txt and NOTICE.md
#


"""
Setup script for installing modela api in python.
Based on http://bbengfort.github.io/programmer/2016/01/20/packaging-with-pypi.html
"""

##########################################################################
## Imports
##########################################################################

import os
import codecs

from setuptools import setup
from setuptools import find_packages

##########################################################################
## Package Information
##########################################################################

## Basic information
## Basic information
NAME         = "modelaapi"
DESCRIPTION  = "A suite of automatic machine learning for kubernetes"
AUTHOR       = "The modelaapi developers"
EMAIL        = "info@modela.ai"
MAINTAINER   = "The modela developers"
LICENSE      = "Apache 2"
REPOSITORY   = "https://github.com/metaptov/modelaapi"
PACKAGE      = "modelaapi"
URL          = "http://www.modela.ai"

## Define the keywords
KEYWORDS = (
    "automl",
    "machine learning",
    "data science",
)

## Define the classifiers
## See https://pypi.python.org/pypi?%3Aaction=list_classifiers
CLASSIFIERS  = (
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "Intended Audience :: Science/Research",
    "License :: OSI Approved :: Apache Software License",
    "Natural Language :: English",
    "Operating System :: OS Independent",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3.5",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Topic :: Software Development",
    "Topic :: Software Development :: Libraries :: Python Modules",    
)

## Important Paths
PROJECT = os.path.abspath(os.path.dirname(__file__))
REQUIRE_PATH = "requirements.txt"
VERSION_PATH = os.path.join(PACKAGE, "version.py")
PKG_DESCRIBE = "DESCRIPTION.md"

## Directories to ignore in find_packages
EXCLUDES = (
    "tests", "tests.*",
    "bin",
    "docs", "docs.*",
    "fixtures",
    "register",
    "notebooks", "notebooks.*",
    "examples", "examples.*",
    "binder", "binder.*",
    "paper",
)

##########################################################################
## Helper Functions
##########################################################################


def read(*parts):
    """
    Assume UTF-8 encoding and return the contents of the file located at the
    absolute path from the REPOSITORY joined with *parts.
    """
    with codecs.open(os.path.join(PROJECT, *parts), "rb", "utf-8") as f:
        return f.read()


def get_version(path=VERSION_PATH):
    """
    Reads the python file defined in the VERSION_PATH to find the get_version
    function, and executes it to ensure that it is loaded correctly. Separating
    the version in this way ensures no additional code is executed.
    """
    namespace = {}
    exec(read(path), namespace)
    return namespace["get_version"](short=True)


def get_requires(path=REQUIRE_PATH):
    """
    Yields a generator of requirements as defined by the REQUIRE_PATH which
    should point to a requirements.txt output by `pip freeze`.
    """
    for line in read(path).splitlines():
        line = line.strip()
        if line and not line.startswith("#"):
            yield line


def get_description_type(path=PKG_DESCRIBE):
    """
    Returns the long_description_content_type based on the extension of the
    package describe path (e.g. .txt, .rst, or .md).
    """
    _, ext = os.path.splitext(path)
    return {".rst": "text/x-rst", ".txt": "text/plain", ".md": "text/markdown"}[ext]


##########################################################################
## Define the configuration
##########################################################################

config = {
    "name": NAME,
    "version": get_version(),
    "description": DESCRIPTION,
    "long_description": read(PKG_DESCRIBE),
    "long_description_content_type": get_description_type(PKG_DESCRIBE),
    "classifiers": CLASSIFIERS,
    "keywords": KEYWORDS,
    "license": LICENSE,
    "author": AUTHOR,
    "author_email": EMAIL,
    "url": URL,
    "maintainer": MAINTAINER,
    "maintainer_email": EMAIL,
    "project_urls": {
        "Documentation": URL,
        "Download": "{}/tarball/v{}".format(REPOSITORY, get_version()),
        "Source": REPOSITORY,
        "Tracker": "{}/issues".format(REPOSITORY),
    },
    "download_url": "{}/tarball/v{}".format(REPOSITORY, get_version()),
    "packages": find_packages(where=PROJECT, exclude=EXCLUDES),
    "package_data": {"yellowbrick": ["datasets/manifest.json"]},
    "zip_safe": False,
    "entry_points": {"console_scripts": []},
    "install_requires": list(get_requires()),
    "python_requires": ">=3.4, <4",
    "setup_requires": ["pytest-runner"],
    "tests_require": ["pytest"],
}


##########################################################################
## Run setup script
##########################################################################

if __name__ == "__main__":
    setup(**config)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/predictor/v1/predictor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCgithub.com/metaprov/modelaapi/services/predictor/v1/predictor.proto\x12\x33github.com.metaprov.modelaapi.services.predictor.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xfa\x01\n\x15ListPredictorsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x66\n\x06labels\x18\x02 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8f\x01\n\x16ListPredictorsResponse\x12\\\n\npredictors\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.PredictorList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x19\n\x17\x43reatePredictorResponse\"q\n\x16\x43reatePredictorRequest\x12W\n\tpredictor\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\xa1\x01\n\x16UpdatePredictorRequest\x12W\n\tpredictor\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x19\n\x17UpdatePredictorResponse\"6\n\x13GetPredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"}\n\x14GetPredictorResponse\x12W\n\tpredictor\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"9\n\x16\x44\x65letePredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17\x44\x65letePredictorResponse\"E\n\x0fRollbackRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmodelName\x18\x03 \x01(\t\"\x12\n\x10RollbackResponse\"T\n\x11PredictOneRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x66ields\x18\x03 \x01(\t\x12\x0e\n\x06values\x18\x04 \x01(\t\"\xe4\x01\n\x12PredictOneResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\r\n\x05score\x18\x04 \x01(\x02\x12\x61\n\x05proba\x18\x05 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry\x1a,\n\nProbaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\x32\x81\x0c\n\x10PredictorService\x12\xcd\x01\n\x0eListPredictors\x12J.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest\x1aK.github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/predictors/{namespace}\x12\xc7\x01\n\x0f\x43reatePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/predictors:\x01*\x12\xce\x01\n\x0cGetPredictor\x12H.github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest\x1aI.github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/predictors/{namespace}/{name}\x12\x80\x02\n\x0fUpdatePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorResponse\"R\x82\xd3\xe4\x93\x02L\x1aG/v1/predictors/{predictor.metadata.namespace}/{predictor.metadata.name}:\x01*\x12\xce\x01\n\x08RollBack\x12\x44.github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest\x1a\x45.github.com.metaprov.modelaapi.services.predictor.v1.RollbackResponse\"5\x82\xd3\xe4\x93\x02/\"*/v1/predictors/{namespace}/{name}:rollback:\x01*\x12\xd7\x01\n\x0f\x44\x65letePredictor\x12K.github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest\x1aL.github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorResponse\")\x82\xd3\xe4\x93\x02#*!/v1/predictors/{namespace}/{name}\x12\xd3\x01\n\nPredictOne\x12\x46.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest\x1aG.github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse\"4\x82\xd3\xe4\x93\x02.\",/v1/predictors/{namespace}/{name}:predictoneB5Z3github.com/metaprov/modelaapi/services/predictor/v1b\x06proto3')



_LISTPREDICTORSREQUEST = DESCRIPTOR.message_types_by_name['ListPredictorsRequest']
_LISTPREDICTORSREQUEST_LABELSENTRY = _LISTPREDICTORSREQUEST.nested_types_by_name['LabelsEntry']
_LISTPREDICTORSRESPONSE = DESCRIPTOR.message_types_by_name['ListPredictorsResponse']
_CREATEPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['CreatePredictorResponse']
_CREATEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['CreatePredictorRequest']
_UPDATEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['UpdatePredictorRequest']
_UPDATEPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['UpdatePredictorResponse']
_GETPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['GetPredictorRequest']
_GETPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['GetPredictorResponse']
_DELETEPREDICTORREQUEST = DESCRIPTOR.message_types_by_name['DeletePredictorRequest']
_DELETEPREDICTORRESPONSE = DESCRIPTOR.message_types_by_name['DeletePredictorResponse']
_ROLLBACKREQUEST = DESCRIPTOR.message_types_by_name['RollbackRequest']
_ROLLBACKRESPONSE = DESCRIPTOR.message_types_by_name['RollbackResponse']
_PREDICTONEREQUEST = DESCRIPTOR.message_types_by_name['PredictOneRequest']
_PREDICTONERESPONSE = DESCRIPTOR.message_types_by_name['PredictOneResponse']
_PREDICTONERESPONSE_PROBAENTRY = _PREDICTONERESPONSE.nested_types_by_name['ProbaEntry']
ListPredictorsRequest = _reflection.GeneratedProtocolMessageType('ListPredictorsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPREDICTORSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPREDICTORSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsRequest)
  })
_sym_db.RegisterMessage(ListPredictorsRequest)
_sym_db.RegisterMessage(ListPredictorsRequest.LabelsEntry)

ListPredictorsResponse = _reflection.GeneratedProtocolMessageType('ListPredictorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.ListPredictorsResponse)
  })
_sym_db.RegisterMessage(ListPredictorsResponse)

CreatePredictorResponse = _reflection.GeneratedProtocolMessageType('CreatePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorResponse)
  })
_sym_db.RegisterMessage(CreatePredictorResponse)

CreatePredictorRequest = _reflection.GeneratedProtocolMessageType('CreatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.CreatePredictorRequest)
  })
_sym_db.RegisterMessage(CreatePredictorRequest)

UpdatePredictorRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorRequest)
  })
_sym_db.RegisterMessage(UpdatePredictorRequest)

UpdatePredictorResponse = _reflection.GeneratedProtocolMessageType('UpdatePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.UpdatePredictorResponse)
  })
_sym_db.RegisterMessage(UpdatePredictorResponse)

GetPredictorRequest = _reflection.GeneratedProtocolMessageType('GetPredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorRequest)
  })
_sym_db.RegisterMessage(GetPredictorRequest)

GetPredictorResponse = _reflection.GeneratedProtocolMessageType('GetPredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.GetPredictorResponse)
  })
_sym_db.RegisterMessage(GetPredictorResponse)

DeletePredictorRequest = _reflection.GeneratedProtocolMessageType('DeletePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorRequest)
  })
_sym_db.RegisterMessage(DeletePredictorRequest)

DeletePredictorResponse = _reflection.GeneratedProtocolMessageType('DeletePredictorResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.DeletePredictorResponse)
  })
_sym_db.RegisterMessage(DeletePredictorResponse)

RollbackRequest = _reflection.GeneratedProtocolMessageType('RollbackRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.RollbackRequest)
  })
_sym_db.RegisterMessage(RollbackRequest)

RollbackResponse = _reflection.GeneratedProtocolMessageType('RollbackResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.RollbackResponse)
  })
_sym_db.RegisterMessage(RollbackResponse)

PredictOneRequest = _reflection.GeneratedProtocolMessageType('PredictOneRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTONEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneRequest)
  })
_sym_db.RegisterMessage(PredictOneRequest)

PredictOneResponse = _reflection.GeneratedProtocolMessageType('PredictOneResponse', (_message.Message,), {

  'ProbaEntry' : _reflection.GeneratedProtocolMessageType('ProbaEntry', (_message.Message,), {
    'DESCRIPTOR' : _PREDICTONERESPONSE_PROBAENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse.ProbaEntry)
    })
  ,
  'DESCRIPTOR' : _PREDICTONERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictor.v1.predictor_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictor.v1.PredictOneResponse)
  })
_sym_db.RegisterMessage(PredictOneResponse)
_sym_db.RegisterMessage(PredictOneResponse.ProbaEntry)

_PREDICTORSERVICE = DESCRIPTOR.services_by_name['PredictorService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/metaprov/modelaapi/services/predictor/v1'
  _LISTPREDICTORSREQUEST_LABELSENTRY._options = None
  _LISTPREDICTORSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _PREDICTONERESPONSE_PROBAENTRY._options = None
  _PREDICTONERESPONSE_PROBAENTRY._serialized_options = b'8\001'
  _PREDICTORSERVICE.methods_by_name['ListPredictors']._options = None
  _PREDICTORSERVICE.methods_by_name['ListPredictors']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/predictors/{namespace}'
  _PREDICTORSERVICE.methods_by_name['CreatePredictor']._options = None
  _PREDICTORSERVICE.methods_by_name['CreatePredictor']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/predictors:\001*'
  _PREDICTORSERVICE.methods_by_name['GetPredictor']._options = None
  _PREDICTORSERVICE.methods_by_name['GetPredictor']._serialized_options = b'\202\323\344\223\002#\022!/v1/predictors/{namespace}/{name}'
  _PREDICTORSERVICE.methods_by_name['UpdatePredictor']._options = None
  _PREDICTORSERVICE.methods_by_name['UpdatePredictor']._serialized_options = b'\202\323\344\223\002L\032G/v1/predictors/{predictor.metadata.namespace}/{predictor.metadata.name}:\001*'
  _PREDICTORSERVICE.methods_by_name['RollBack']._options = None
  _PREDICTORSERVICE.methods_by_name['RollBack']._serialized_options = b'\202\323\344\223\002/\"*/v1/predictors/{namespace}/{name}:rollback:\001*'
  _PREDICTORSERVICE.methods_by_name['DeletePredictor']._options = None
  _PREDICTORSERVICE.methods_by_name['DeletePredictor']._serialized_options = b'\202\323\344\223\002#*!/v1/predictors/{namespace}/{name}'
  _PREDICTORSERVICE.methods_by_name['PredictOne']._options = None
  _PREDICTORSERVICE.methods_by_name['PredictOne']._serialized_options = b'\202\323\344\223\002.\",/v1/predictors/{namespace}/{name}:predictone'
  _LISTPREDICTORSREQUEST._serialized_start=264
  _LISTPREDICTORSREQUEST._serialized_end=514
  _LISTPREDICTORSREQUEST_LABELSENTRY._serialized_start=469
  _LISTPREDICTORSREQUEST_LABELSENTRY._serialized_end=514
  _LISTPREDICTORSRESPONSE._serialized_start=517
  _LISTPREDICTORSRESPONSE._serialized_end=660
  _CREATEPREDICTORRESPONSE._serialized_start=662
  _CREATEPREDICTORRESPONSE._serialized_end=687
  _CREATEPREDICTORREQUEST._serialized_start=689
  _CREATEPREDICTORREQUEST._serialized_end=802
  _UPDATEPREDICTORREQUEST._serialized_start=805
  _UPDATEPREDICTORREQUEST._serialized_end=966
  _UPDATEPREDICTORRESPONSE._serialized_start=968
  _UPDATEPREDICTORRESPONSE._serialized_end=993
  _GETPREDICTORREQUEST._serialized_start=995
  _GETPREDICTORREQUEST._serialized_end=1049
  _GETPREDICTORRESPONSE._serialized_start=1051
  _GETPREDICTORRESPONSE._serialized_end=1176
  _DELETEPREDICTORREQUEST._serialized_start=1178
  _DELETEPREDICTORREQUEST._serialized_end=1235
  _DELETEPREDICTORRESPONSE._serialized_start=1237
  _DELETEPREDICTORRESPONSE._serialized_end=1262
  _ROLLBACKREQUEST._serialized_start=1264
  _ROLLBACKREQUEST._serialized_end=1333
  _ROLLBACKRESPONSE._serialized_start=1335
  _ROLLBACKRESPONSE._serialized_end=1353
  _PREDICTONEREQUEST._serialized_start=1355
  _PREDICTONEREQUEST._serialized_end=1439
  _PREDICTONERESPONSE._serialized_start=1442
  _PREDICTONERESPONSE._serialized_end=1670
  _PREDICTONERESPONSE_PROBAENTRY._serialized_start=1626
  _PREDICTONERESPONSE_PROBAENTRY._serialized_end=1670
  _PREDICTORSERVICE._serialized_start=1673
  _PREDICTORSERVICE._serialized_end=3210
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.dataproductversion.v1 import dataproductversion_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2


class DataProductVersionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataProductVersions = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/ListDataProductVersions',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.ListDataProductVersionsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.ListDataProductVersionsResponse.FromString,
                )
        self.CreateDataProductVersion = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/CreateDataProductVersion',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.CreateDataProductVersionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.CreateDataProductVersionResponse.FromString,
                )
        self.GetDataProductVersion = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/GetDataProductVersion',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.GetDataProductVersionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.GetDataProductVersionResponse.FromString,
                )
        self.UpdateDataProductVersion = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/UpdateDataProductVersion',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.UpdateDataProductVersionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.UpdateDataProductVersionResponse.FromString,
                )
        self.DeleteDataProductVersion = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/DeleteDataProductVersion',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.DeleteDataProductVersionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.DeleteDataProductVersionResponse.FromString,
                )


class DataProductVersionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataProductVersions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataProductVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataProductVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataProductVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataProductVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataProductVersionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataProductVersions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataProductVersions,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.ListDataProductVersionsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.ListDataProductVersionsResponse.SerializeToString,
            ),
            'CreateDataProductVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataProductVersion,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.CreateDataProductVersionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.CreateDataProductVersionResponse.SerializeToString,
            ),
            'GetDataProductVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataProductVersion,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.GetDataProductVersionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.GetDataProductVersionResponse.SerializeToString,
            ),
            'UpdateDataProductVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataProductVersion,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.UpdateDataProductVersionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.UpdateDataProductVersionResponse.SerializeToString,
            ),
            'DeleteDataProductVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataProductVersion,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.DeleteDataProductVersionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.DeleteDataProductVersionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataProductVersionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataProductVersions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/ListDataProductVersions',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.ListDataProductVersionsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.ListDataProductVersionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataProductVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/CreateDataProductVersion',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.CreateDataProductVersionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.CreateDataProductVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataProductVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/GetDataProductVersion',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.GetDataProductVersionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.GetDataProductVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataProductVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/UpdateDataProductVersion',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.UpdateDataProductVersionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.UpdateDataProductVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataProductVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproductversion.v1.DataProductVersionService/DeleteDataProductVersion',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.DeleteDataProductVersionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproductversion_dot_v1_dot_dataproductversion__pb2.DeleteDataProductVersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.cronreport.v1 import cronreport_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2


class CronReportServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListCronReports = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/ListCronReports',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ListCronReportsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ListCronReportsResponse.FromString,
                )
        self.CreateCronReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/CreateCronReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.CreateCronReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.CreateCronReportResponse.FromString,
                )
        self.GetCronReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/GetCronReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.GetCronReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.GetCronReportResponse.FromString,
                )
        self.UpdateCronReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/UpdateCronReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.UpdateCronReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.UpdateCronReportResponse.FromString,
                )
        self.DeleteCronReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/DeleteCronReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.DeleteCronReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.DeleteCronReportResponse.FromString,
                )
        self.RunReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/RunReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.RunCronReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.RunCronReportResponse.FromString,
                )
        self.PauseCronReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/PauseCronReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.PauseCronReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.PauseCronReportResponse.FromString,
                )
        self.ResumeCronReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/ResumeCronReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ResumeCronReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ResumeCronReportResponse.FromString,
                )


class CronReportServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListCronReports(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateCronReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCronReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateCronReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCronReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseCronReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeCronReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CronReportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListCronReports': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCronReports,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ListCronReportsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ListCronReportsResponse.SerializeToString,
            ),
            'CreateCronReport': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateCronReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.CreateCronReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.CreateCronReportResponse.SerializeToString,
            ),
            'GetCronReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCronReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.GetCronReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.GetCronReportResponse.SerializeToString,
            ),
            'UpdateCronReport': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateCronReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.UpdateCronReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.UpdateCronReportResponse.SerializeToString,
            ),
            'DeleteCronReport': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCronReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.DeleteCronReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.DeleteCronReportResponse.SerializeToString,
            ),
            'RunReport': grpc.unary_unary_rpc_method_handler(
                    servicer.RunReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.RunCronReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.RunCronReportResponse.SerializeToString,
            ),
            'PauseCronReport': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseCronReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.PauseCronReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.PauseCronReportResponse.SerializeToString,
            ),
            'ResumeCronReport': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeCronReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ResumeCronReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ResumeCronReportResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CronReportService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListCronReports(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/ListCronReports',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ListCronReportsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ListCronReportsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateCronReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/CreateCronReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.CreateCronReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.CreateCronReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCronReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/GetCronReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.GetCronReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.GetCronReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateCronReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/UpdateCronReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.UpdateCronReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.UpdateCronReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCronReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/DeleteCronReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.DeleteCronReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.DeleteCronReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/RunReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.RunCronReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.RunCronReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseCronReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/PauseCronReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.PauseCronReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.PauseCronReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeCronReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.cronreport.v1.CronReportService/ResumeCronReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ResumeCronReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_cronreport_dot_v1_dot_cronreport__pb2.ResumeCronReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/publisherd/v1/publisherd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/publisherd/v1/publisherd.proto\x12\x34github.com.metaprov.modelaapi.services.publisherd.v1\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\xff\x02\n\x16PublishNotebookRequest\x12\x14\n\x0cnotebookName\x18\x01 \x01(\t\x12\x19\n\x11notebookNamespace\x18\x02 \x01(\t\x12\\\n\x0cnotebookSpec\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookSpec\x12\x17\n\x0fNotebookContent\x18\x04 \x01(\t\x12\x12\n\nDockerfile\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\",\n\x17PublishNotebookResponse\x12\x11\n\tImageName\x18\x01 \x01(\t\"\xe9\t\n\x13PublishModelRequest\x12V\n\x0b\x64\x61taproduct\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12\x64\n\x12\x64\x61taproductversion\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05model\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x06 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x11\n\timagename\x18\x08 \x01(\t\x12\x1c\n\x14imagenameWithVersion\x18\t \x01(\t\x12\x0c\n\x04push\x18\n \x01(\x08\x12T\n\x06\x62ucket\x18\x0b \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\tcloudConn\x18\x0c \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12o\n\x0b\x63loudSecret\x18\r \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.publisherd.v1.PublishModelRequest.CloudSecretEntry\x12[\n\x10\x64ockerConnection\x18\x0e \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x81\x01\n\x14\x64ockerRegistrySecret\x18\x0f \x03(\x0b\x32\x63.github.com.metaprov.modelaapi.services.publisherd.v1.PublishModelRequest.DockerRegistrySecretEntry\x12\x0e\n\x06kaniko\x18\x13 \x01(\x08\x1a\x32\n\x10\x43loudSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a;\n\x19\x44ockerRegistrySecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"7\n\x14PublishModelResponse\x12\x11\n\tImageName\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\"\xea\x06\n\x13PackageModelRequest\x12V\n\x0b\x64\x61taproduct\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12\x64\n\x12\x64\x61taproductversion\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05model\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12N\n\x05study\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x06 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\tcloudConn\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12o\n\x0b\x63loudSecret\x18\t \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.publisherd.v1.PackageModelRequest.CloudSecretEntry\x1a\x32\n\x10\x43loudSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"4\n\x14PackageModelResponse\x12\x0e\n\x06tarUri\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\t\"\x11\n\x0fShutdownRequest\"\x12\n\x10ShutdownResponse2\xb8\x05\n\x11PublisherdService\x12\xa7\x01\n\x0cPackageModel\x12I.github.com.metaprov.modelaapi.services.publisherd.v1.PackageModelRequest\x1aJ.github.com.metaprov.modelaapi.services.publisherd.v1.PackageModelResponse\"\x00\x12\xa7\x01\n\x0cPublishModel\x12I.github.com.metaprov.modelaapi.services.publisherd.v1.PublishModelRequest\x1aJ.github.com.metaprov.modelaapi.services.publisherd.v1.PublishModelResponse\"\x00\x12\xb0\x01\n\x0fPublishNotebook\x12L.github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest\x1aM.github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookResponse\"\x00\x12\x9b\x01\n\x08Shutdown\x12\x45.github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownRequest\x1a\x46.github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownResponse\"\x00\x42\x36Z4github.com/metaprov/modelaapi/services/publisherd/v1b\x06proto3')



_PUBLISHNOTEBOOKREQUEST = DESCRIPTOR.message_types_by_name['PublishNotebookRequest']
_PUBLISHNOTEBOOKREQUEST_SECRETENTRY = _PUBLISHNOTEBOOKREQUEST.nested_types_by_name['SecretEntry']
_PUBLISHNOTEBOOKRESPONSE = DESCRIPTOR.message_types_by_name['PublishNotebookResponse']
_PUBLISHMODELREQUEST = DESCRIPTOR.message_types_by_name['PublishModelRequest']
_PUBLISHMODELREQUEST_CLOUDSECRETENTRY = _PUBLISHMODELREQUEST.nested_types_by_name['CloudSecretEntry']
_PUBLISHMODELREQUEST_DOCKERREGISTRYSECRETENTRY = _PUBLISHMODELREQUEST.nested_types_by_name['DockerRegistrySecretEntry']
_PUBLISHMODELRESPONSE = DESCRIPTOR.message_types_by_name['PublishModelResponse']
_PACKAGEMODELREQUEST = DESCRIPTOR.message_types_by_name['PackageModelRequest']
_PACKAGEMODELREQUEST_CLOUDSECRETENTRY = _PACKAGEMODELREQUEST.nested_types_by_name['CloudSecretEntry']
_PACKAGEMODELRESPONSE = DESCRIPTOR.message_types_by_name['PackageModelResponse']
_SHUTDOWNREQUEST = DESCRIPTOR.message_types_by_name['ShutdownRequest']
_SHUTDOWNRESPONSE = DESCRIPTOR.message_types_by_name['ShutdownResponse']
PublishNotebookRequest = _reflection.GeneratedProtocolMessageType('PublishNotebookRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHNOTEBOOKREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _PUBLISHNOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookRequest)
  })
_sym_db.RegisterMessage(PublishNotebookRequest)
_sym_db.RegisterMessage(PublishNotebookRequest.SecretEntry)

PublishNotebookResponse = _reflection.GeneratedProtocolMessageType('PublishNotebookResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHNOTEBOOKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishNotebookResponse)
  })
_sym_db.RegisterMessage(PublishNotebookResponse)

PublishModelRequest = _reflection.GeneratedProtocolMessageType('PublishModelRequest', (_message.Message,), {

  'CloudSecretEntry' : _reflection.GeneratedProtocolMessageType('CloudSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHMODELREQUEST_CLOUDSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishModelRequest.CloudSecretEntry)
    })
  ,

  'DockerRegistrySecretEntry' : _reflection.GeneratedProtocolMessageType('DockerRegistrySecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _PUBLISHMODELREQUEST_DOCKERREGISTRYSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishModelRequest.DockerRegistrySecretEntry)
    })
  ,
  'DESCRIPTOR' : _PUBLISHMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishModelRequest)
  })
_sym_db.RegisterMessage(PublishModelRequest)
_sym_db.RegisterMessage(PublishModelRequest.CloudSecretEntry)
_sym_db.RegisterMessage(PublishModelRequest.DockerRegistrySecretEntry)

PublishModelResponse = _reflection.GeneratedProtocolMessageType('PublishModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PublishModelResponse)
  })
_sym_db.RegisterMessage(PublishModelResponse)

PackageModelRequest = _reflection.GeneratedProtocolMessageType('PackageModelRequest', (_message.Message,), {

  'CloudSecretEntry' : _reflection.GeneratedProtocolMessageType('CloudSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _PACKAGEMODELREQUEST_CLOUDSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PackageModelRequest.CloudSecretEntry)
    })
  ,
  'DESCRIPTOR' : _PACKAGEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PackageModelRequest)
  })
_sym_db.RegisterMessage(PackageModelRequest)
_sym_db.RegisterMessage(PackageModelRequest.CloudSecretEntry)

PackageModelResponse = _reflection.GeneratedProtocolMessageType('PackageModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _PACKAGEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.PackageModelResponse)
  })
_sym_db.RegisterMessage(PackageModelResponse)

ShutdownRequest = _reflection.GeneratedProtocolMessageType('ShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownRequest)
  })
_sym_db.RegisterMessage(ShutdownRequest)

ShutdownResponse = _reflection.GeneratedProtocolMessageType('ShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _SHUTDOWNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.publisherd.v1.publisherd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.publisherd.v1.ShutdownResponse)
  })
_sym_db.RegisterMessage(ShutdownResponse)

_PUBLISHERDSERVICE = DESCRIPTOR.services_by_name['PublisherdService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/publisherd/v1'
  _PUBLISHNOTEBOOKREQUEST_SECRETENTRY._options = None
  _PUBLISHNOTEBOOKREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _PUBLISHMODELREQUEST_CLOUDSECRETENTRY._options = None
  _PUBLISHMODELREQUEST_CLOUDSECRETENTRY._serialized_options = b'8\001'
  _PUBLISHMODELREQUEST_DOCKERREGISTRYSECRETENTRY._options = None
  _PUBLISHMODELREQUEST_DOCKERREGISTRYSECRETENTRY._serialized_options = b'8\001'
  _PACKAGEMODELREQUEST_CLOUDSECRETENTRY._options = None
  _PACKAGEMODELREQUEST_CLOUDSECRETENTRY._serialized_options = b'8\001'
  _PUBLISHNOTEBOOKREQUEST._serialized_start=343
  _PUBLISHNOTEBOOKREQUEST._serialized_end=726
  _PUBLISHNOTEBOOKREQUEST_SECRETENTRY._serialized_start=681
  _PUBLISHNOTEBOOKREQUEST_SECRETENTRY._serialized_end=726
  _PUBLISHNOTEBOOKRESPONSE._serialized_start=728
  _PUBLISHNOTEBOOKRESPONSE._serialized_end=772
  _PUBLISHMODELREQUEST._serialized_start=775
  _PUBLISHMODELREQUEST._serialized_end=2032
  _PUBLISHMODELREQUEST_CLOUDSECRETENTRY._serialized_start=1921
  _PUBLISHMODELREQUEST_CLOUDSECRETENTRY._serialized_end=1971
  _PUBLISHMODELREQUEST_DOCKERREGISTRYSECRETENTRY._serialized_start=1973
  _PUBLISHMODELREQUEST_DOCKERREGISTRYSECRETENTRY._serialized_end=2032
  _PUBLISHMODELRESPONSE._serialized_start=2034
  _PUBLISHMODELRESPONSE._serialized_end=2089
  _PACKAGEMODELREQUEST._serialized_start=2092
  _PACKAGEMODELREQUEST._serialized_end=2966
  _PACKAGEMODELREQUEST_CLOUDSECRETENTRY._serialized_start=1921
  _PACKAGEMODELREQUEST_CLOUDSECRETENTRY._serialized_end=1971
  _PACKAGEMODELRESPONSE._serialized_start=2968
  _PACKAGEMODELRESPONSE._serialized_end=3020
  _SHUTDOWNREQUEST._serialized_start=3022
  _SHUTDOWNREQUEST._serialized_end=3039
  _SHUTDOWNRESPONSE._serialized_start=3041
  _SHUTDOWNRESPONSE._serialized_end=3059
  _PUBLISHERDSERVICE._serialized_start=3062
  _PUBLISHERDSERVICE._serialized_end=3758
# @@protoc_insertion_point(module_scope)
